@@ -1,10 +1,11 @@
 package SVG::Estimate::Circle;
-$SVG::Estimate::Circle::VERSION = '1.0105';
+$SVG::Estimate::Circle::VERSION = '1.0107';
 use Moo;
 use Math::Trig qw/pi/;
 
 extends 'SVG::Estimate::Shape';
 with 'SVG::Estimate::Role::MakePolygon';
+with 'SVG::Estimate::Role::ArgsWithUnits';
 
 =head1 NAME
 
@@ -12,7 +13,7 @@ SVG::Estimate::Circle - Handles estimating circles.
 
 =head1 VERSION
 
-version 1.0105
+version 1.0107
 
 =head1 SYNOPSIS
 
@@ -56,16 +57,23 @@ Float representing the radius.
 
 has cx => (
     is => 'ro',
+    default => sub { 0 },
 );
 
 has cy => (
     is => 'ro',
+    default => sub { 0 },
 );
 
 has r => (
     is => 'ro',
+    required => 1,
 );
 
+sub args_with_units {
+    return qw/r/;
+}
+
 sub BUILDARGS {
     my ($class, @args) = @_;
     ##Upgrade to hashref
