@@ -1,10 +1,11 @@
 package SVG::Estimate::Ellipse;
-$SVG::Estimate::Ellipse::VERSION = '1.0105';
+$SVG::Estimate::Ellipse::VERSION = '1.0107';
 use Moo;
 use Math::Trig qw/pi/;
 
 extends 'SVG::Estimate::Shape';
 with 'SVG::Estimate::Role::MakePolygon';
+with 'SVG::Estimate::Role::ArgsWithUnits';
 
 =head1 NAME
 
@@ -12,7 +13,7 @@ SVG::Estimate::Ellipse - Handles estimating ellipses.
 
 =head1 VERSION
 
-version 1.0105
+version 1.0107
 
 =head1 SYNOPSIS
 
@@ -61,18 +62,22 @@ Float representing the y radius.
 
 has cx => (
     is => 'ro',
+    default => sub { 0 },
 );
 
 has cy => (
     is => 'ro',
+    default => sub { 0 },
 );
 
 has rx => (
     is => 'ro',
+    required => 1,
 );
 
 has ry => (
     is => 'ro',
+    required => 1,
 );
 
 sub BUILDARGS {
@@ -107,6 +112,10 @@ sub BUILDARGS {
     return $args;
 }
 
+sub args_with_units {
+    return qw/rx ry/;
+}
+
 sub this_point {
     my $class = shift;
     my $args  = shift;
